@@ -23,7 +23,7 @@ sub new {
             LIBSUFFIX     => '.a',
             SHLIBPREFIX   => 'lib',
             LDMODULEFLAGS => ['-shared'],
-            INSTALL       => 'install',
+            CCDLFLAGS     => ['-fPIC'], # TODO: rename
         );
         my %win32 = (
             CC  => $ENV{CC}  || 'gcc',
@@ -33,12 +33,17 @@ sub new {
             LIBPREFIX   => '',
             LIBSUFFIX   => '.lib',
             SHLIBPREFIX => '',
-            INSTALL       => 'copy',
+            CCDLFLAGS   => [], # TODO: rename
         );
         my %darwin = ( LDMODULEFLAGS => ['-dynamiclib'], );
+        my %solaris = (
+            CCDLFLAGS     => ['-kPIC'],
+            LDMODULEFLAGS => ['-G'],
+        );
 
-          $^O eq 'MSWin32' ? %win32
-        : $^O eq 'darwin'  ? (%unix, %darwin)
+          $^O eq 'MSWin32'  ? %win32
+        : $^O eq 'darwin'   ? (%unix, %darwin)
+        : $^O eq 'solaris'  ? (%unix, %solaris)
         : %unix;
     };
 
@@ -49,7 +54,6 @@ sub new {
         CPPPATH       => [],
         LIBS          => [],
         LIBPATH       => [],
-        CCCDLFLAGS    => [], # TODO: rename
         SHLIBSUFFIX   => '.' . $Config{so},
         RANLIB        => 'ranlib',
         PROGSUFFIX    => ( $Config{exe_ext} ? ( '.' . $Config{exe_ext} ) : '' ),
@@ -108,7 +112,9 @@ sub install_lib {
 sub install {
     my ($self, $target, $suffix) = @_;
     my $dst = File::Spec->catfile($self->{PREFIX}, $suffix);
-    push @{$Module::Install::ForC::INSTALL{$suffix}}, "$self->{INSTALL} $target $dst";
+    ($target =~ m{['"\n\{\}]}) and die "invalid file name for install: $target";
+    ($suffix =~ m{['"\n\{\}]}) and die "invalid file name for install: $suffix";
+    push @{$Module::Install::ForC::INSTALL{$suffix}}, "\$(PERL) -e 'use File::Copy; File::Copy::copy(q{$target}, q{$dst}) or die qq{Copy failed: $!}'";
 }
 
 sub try_cc {
